@@ -3,12 +3,13 @@ Puppet::Type.type(:neutron_agent_linuxbridge).provide(
   :parent => Puppet::Type.type(:openstack_config).provider(:ini_setting)
 ) do
 
+  def self.file_path
+    '/etc/neutron/plugins/ml2/linuxbridge_agent.ini'
+  end
+
+  # added for backwards compatibility with older versions of inifile
   def file_path
-    if Facter.value(:operatingsystem) == 'Ubuntu'
-      '/etc/neutron/plugins/ml2/ml2_conf.ini'
-    else
-      '/etc/neutron/plugins/linuxbridge/linuxbridge_conf.ini'
-    end
+    self.class.file_path
   end
 
 end
