@@ -7,14 +7,25 @@ Puppet::Type.newtype(:neutron_config) do
     newvalues(/\S+\/\S+/)
   end
 
-  newproperty(:value) do
+  newproperty(:value, :array_matching => :all) do
     desc 'The value of the setting to be defined.'
+    def insync?(is)
+      return true if @should.empty?
+      return false unless is.is_a? Array
+      return false unless is.length == @should.length
+      # we don't care about the order of items in array, hence
+      # it is necessary to override insync
+      return (
+        is & @should == is or
+        is & @should.map(&:to_s) == is
+      )
+    end
+
     munge do |value|
       value = value.to_s.strip
       value.capitalize! if value =~ /^(true|false)$/i
       value
     end
-    newvalues(/^[\S ]*$/)
 
     def is_to_s( currentvalue )
       if resource.secret?
@@ -50,8 +61,8 @@ Puppet::Type.newtype(:neutron_config) do
       provider.create
   end
 
-  autorequire(:package) do
-    'neutron'
+  autorequire(:anchor) do
+    ['neutron::install::end']
   end
 
 end
