@@ -57,6 +57,7 @@ describe 'neutron::config' do
   shared_examples 'neutron_agent_config' do
     let :params do
       { :ovs_agent_config         => config_hash,
+        :ovn_agent_config         => config_hash,
         :sriov_agent_config       => config_hash,
         :linuxbridge_agent_config => config_hash,
         :macvtap_agent_config     => config_hash,
@@ -76,6 +77,12 @@ describe 'neutron::config' do
       should contain_neutron_agent_ovs('DEFAULT/baz').with_ensure('absent')
     end
 
+    it 'configures arbitrary neutron_agent_ovn configurations' do
+      should contain_neutron_agent_ovn('DEFAULT/foo').with_value('fooValue')
+      should contain_neutron_agent_ovn('DEFAULT/bar').with_value('barValue')
+      should contain_neutron_agent_ovn('DEFAULT/baz').with_ensure('absent')
+    end
+
     it 'configures arbitrary neutron_sriov_agent_config configurations' do
       should contain_neutron_sriov_agent_config('DEFAULT/foo').with_value('fooValue')
       should contain_neutron_sriov_agent_config('DEFAULT/bar').with_value('barValue')
@@ -141,19 +148,12 @@ describe 'neutron::config' do
   shared_examples 'neutron_plugin_config' do
     let :params do
       {
-        :plugin_nsx_config             => config_hash,
         :plugin_opencontrail_config    => config_hash,
         :plugin_nuage_config           => config_hash,
         :plugin_ml2_config             => config_hash
       }
     end
 
-    it 'configures arbitrary neutron_plugin_nsx configurations' do
-      should contain_neutron_plugin_nsx('DEFAULT/foo').with_value('fooValue')
-      should contain_neutron_plugin_nsx('DEFAULT/bar').with_value('barValue')
-      should contain_neutron_plugin_nsx('DEFAULT/baz').with_ensure('absent')
-    end
-
     it 'configures arbitrary neutron_plugin_opencontrail configurations' do
       should contain_neutron_plugin_opencontrail('DEFAULT/foo').with_value('fooValue')
       should contain_neutron_plugin_opencontrail('DEFAULT/bar').with_value('barValue')
