@@ -28,6 +28,7 @@ describe 'neutron::plugins::ml2::ovn' do
       :dns_servers                          => '<SERVICE DEFAULT>',
       :vhostuser_socket_dir                 => '<SERVICE DEFAULT>',
       :ovn_emit_need_to_frag                => '<SERVICE DEFAULT>',
+      :localnet_learn_fdb                   => '<SERVICE DEFAULT>',
       :network_log_rate_limit               => '<SERVICE DEFAULT>',
       :network_log_burst_limit              => '<SERVICE DEFAULT>',
       :network_log_local_output_log_base    => '<SERVICE DEFAULT>',
@@ -63,6 +64,7 @@ describe 'neutron::plugins::ml2::ovn' do
         should contain_neutron_plugin_ml2('ovn/dns_servers').with_value(p[:dns_servers])
         should contain_neutron_plugin_ml2('ovn/vhost_sock_dir').with_value(p[:vhostuser_socket_dir])
         should contain_neutron_plugin_ml2('ovn/ovn_emit_need_to_frag').with_value(p[:ovn_emit_need_to_frag])
+        should contain_neutron_plugin_ml2('ovn/localnet_learn_fdb').with_value(p[:localnet_learn_fdb])
         should contain_neutron_plugin_ml2('network_log/rate_limit').with_value(p[:network_log_rate_limit])
         should contain_neutron_plugin_ml2('network_log/burst_limit').with_value(p[:network_log_burst_limit])
         should contain_neutron_plugin_ml2('network_log/local_output_log_base').with_value(p[:network_log_local_output_log_base])
@@ -88,6 +90,7 @@ describe 'neutron::plugins::ml2::ovn' do
           :disable_ovn_dhcp_for_baremetal_ports => false,
           :dns_servers                          => '8.8.8.8,10.10.10.10',
           :ovn_emit_need_to_frag                => false,
+          :localnet_learn_fdb                   => false,
         }
       end
 
@@ -109,6 +112,7 @@ describe 'neutron::plugins::ml2::ovn' do
         should contain_neutron_plugin_ml2('ovn/dns_servers').with_value(p[:dns_servers])
         should contain_neutron_plugin_ml2('ovn/vhost_sock_dir').with_value(p[:vhostuser_socket_dir])
         should contain_neutron_plugin_ml2('ovn/ovn_emit_need_to_frag').with_value(p[:ovn_emit_need_to_frag])
+        should contain_neutron_plugin_ml2('ovn/localnet_learn_fdb').with_value(p[:localnet_learn_fdb])
         should contain_neutron_plugin_ml2('network_log/rate_limit').with_value(p[:network_log_rate_limit])
         should contain_neutron_plugin_ml2('network_log/burst_limit').with_value(p[:network_log_burst_limit])
         should contain_neutron_plugin_ml2('network_log/local_output_log_base').with_value(p[:network_log_local_output_log_base])
